@@ -3,10 +3,6 @@ package Crypt::Mode;
 use strict;
 use warnings;
 
-use Exporter 'import';
-our @EXPORT_OK = qw(
-);
-
 ### METHODS
 
 sub new { die }    # overriden in subclass
@@ -60,4 +56,6 @@ sub _finish {
   return undef;
 }
 
+sub CLONE_SKIP { 1 } # XXX-FIXME for now just prevent cloning
+
 1;
\ No newline at end of file
